==> eiffelstudio-18.07.10.1981.tar: F_code/C11/co515.c <==
/*
 * Code for class CONF_LIBRARY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co515.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CONF_LIBRARY}.make */
void F1156_10441 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,arg2);
	RTLR(2,arg3);
	RTLR(3,Current);
	RTLIU(4);
	
	RTEAA("make", 1155, Current, 0, 3, 16192);
	RTGC;
	RTHOOK(1);
	F1148_10294(Current, arg1, arg2, arg3);
	RTHOOK(2);
	*(EIF_BOOLEAN *)(Current + O8129[Dtype(Current)-1147]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {CONF_LIBRARY}.is_library */
static EIF_BOOLEAN F1156_10442_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	

	
	RTEAA("is_library", 1155, Current, 0, 0, 16193);
	RTOSP (10442);
#define Result RTOSR(10442)
	RTHOOK(1);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTOSE (10442);
	RTHOOK(2);
	RTEE;
	return Result;
#undef Result
}

EIF_BOOLEAN F1156_10442 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(10442,F1156_10442_body,(Current));
}

/* {CONF_LIBRARY}.is_readonly */
EIF_BOOLEAN F1156_10443 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTCDT;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("is_readonly", 1155, Current, 1, 0, 16194);
	RTGC;
	RTHOOK(1);
	if (*(EIF_BOOLEAN *)(Current + O8119[dtype-1147])) {
		RTHOOK(2);
		RTHOOK(3);
		RTLE;
		RTEE;
		return (EIF_BOOLEAN) *(EIF_BOOLEAN *)(Current + O8129[dtype-1147]);
	} else {
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_18_);
		loc1 = tr1;
		if (EIF_TEST(loc1)) {
			RTHOOK(5);
			tr1 = *(EIF_REFERENCE *)(loc1 + _REFACS_7_);
			Result = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_15_3_);
		} else {
			RTHOOK(6);
			RTHOOK(7);
			RTLE;
			RTEE;
			return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		}
	}
	RTHOOK(8);
	RTLE;
	RTEE;
	return Result;
}

/* {CONF_LIBRARY}.library_target */
EIF_REFERENCE F1156_10445 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_18_);
}


/* {CONF_LIBRARY}.mapping */
EIF_REFERENCE F1156_10446 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("mapping", 1155, Current, 1, 0, 16197);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_18_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTHOOK(2);
		tr1 = F1084_10051(loc1);
		RTHOOK(3);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) tr1;
	} else {
		RTHOOK(4);
		{
			static EIF_TYPE_INDEX typarr0[] = {831,1064,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
			tr1 = RTLNS(typres0.id, 831, _OBJSIZ_7_4_0_7_0_0_0_0_);
		}
		F823_7518(RTCW(tr1), ((EIF_INTEGER_32) 0L));
		RTHOOK(5);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) tr1;
	}/* NOTREACHED */
	
}

/* {CONF_LIBRARY}.class_by_name */
EIF_REFERENCE F1156_10448 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(9);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,loc3);
	RTLR(3,arg1);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,Result);
	RTLR(7,loc4);
	RTLR(8,loc5);
	RTLIU(9);
	
	RTEAA("class_by_name", 1155, Current, 5, 2, 16182);
	RTGC;
	RTHOOK(1);
	loc2 = F1156_10446(Current);
	RTHOOK(2);
	tb1 = '\0';
	if ((EIF_BOOLEAN)(loc2 != NULL)) {
		tr1 = F823_7521(RTCW(loc2), arg1);
		loc3 = tr1;
		tb1 = EIF_TEST(loc3);
	}
	if (tb1) {
		RTHOOK(3);
		loc1 = (EIF_REFERENCE) loc3;
	} else {
		RTHOOK(4);
		loc1 = (EIF_REFERENCE) arg1;
	}
	RTHOOK(5);
	{
		static EIF_TYPE_INDEX typarr0[] = {919,1079,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNS(typres0.id, 919, _OBJSIZ_2_3_0_1_0_0_0_0_);
	}
	F916_7815(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(6);
	tb1 = '\0';
	tb2 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_10_);
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		tr1 = F823_7521(loc4, loc1);
		loc5 = tr1;
		tb2 = EIF_TEST(loc5);
	}
	if (tb2) {
		tb2 = F1080_9898(loc5);
		tb1 = (EIF_BOOLEAN) !tb2;
	}
	if (tb1) {
		RTHOOK(7);
		F920_7879(RTCW(Result), loc5);
	}
	RTHOOK(8);
	RTLE;
	RTEE;
	return Result;
}

/* {CONF_LIBRARY}.set_use_application_options */
void F1156_10452 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_use_application_options", 1155, Current, 0, 1, 16186);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current + O8180[Dtype(Current)-1155]) = (EIF_BOOLEAN) arg1;
	RTHOOK(2);
	RTEE;
}

/* {CONF_LIBRARY}.process */
void F1156_10454 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("process", 1155, Current, 0, 1, 16188);
	RTGC;
	RTHOOK(1);
	F1148_10345(Current, arg1);
	RTHOOK(2);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9210[Dtype(arg1)-1267])(RTCW(arg1), Current);
	RTHOOK(3);
	RTLE;
	RTEE;
}

void EIF_Minit515 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C11/co515.c <==
/*
 * Code for class CONF_LIBRARY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co515.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CONF_LIBRARY}.make */
void F1156_10469 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,arg2);
	RTLR(2,arg3);
	RTLR(3,Current);
	RTLIU(4);
	
	RTEAA("make", 1155, Current, 0, 3, 16250);
	RTGC;
	RTHOOK(1);
	F1148_10315(Current, arg1, arg2, arg3);
	RTHOOK(2);
	*(EIF_BOOLEAN *)(Current + O8129[Dtype(Current)-1147]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {CONF_LIBRARY}.is_library */
static EIF_BOOLEAN F1156_10470_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	

	
	RTEAA("is_library", 1155, Current, 0, 0, 16251);
	RTOSP (10470);
#define Result RTOSR(10470)
	RTHOOK(1);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTOSE (10470);
	RTHOOK(2);
	RTEE;
	return Result;
#undef Result
}

EIF_BOOLEAN F1156_10470 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(10470,F1156_10470_body,(Current));
}

/* {CONF_LIBRARY}.is_readonly */
EIF_BOOLEAN F1156_10471 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTCDT;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("is_readonly", 1155, Current, 1, 0, 16252);
	RTGC;
	RTHOOK(1);
	if (*(EIF_BOOLEAN *)(Current + O8119[dtype-1147])) {
		RTHOOK(2);
		RTHOOK(3);
		RTLE;
		RTEE;
		return (EIF_BOOLEAN) *(EIF_BOOLEAN *)(Current + O8129[dtype-1147]);
	} else {
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_18_);
		loc1 = tr1;
		if (EIF_TEST(loc1)) {
			RTHOOK(5);
			tr1 = *(EIF_REFERENCE *)(loc1 + _REFACS_7_);
			Result = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_16_3_);
		} else {
			RTHOOK(6);
			RTHOOK(7);
			RTLE;
			RTEE;
			return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		}
	}
	RTHOOK(8);
	RTLE;
	RTEE;
	return Result;
}

/* {CONF_LIBRARY}.mapping */
EIF_REFERENCE F1156_10474 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("mapping", 1155, Current, 1, 0, 16255);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_18_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTHOOK(2);
		tr1 = F1084_10070(loc1);
		RTHOOK(3);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) tr1;
	} else {
		RTHOOK(4);
		{
			static EIF_TYPE_INDEX typarr0[] = {826,1064,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
			tr1 = RTLNS(typres0.id, 826, _OBJSIZ_7_4_0_7_0_0_0_0_);
		}
		F818_7220(RTCW(tr1), ((EIF_INTEGER_32) 0L));
		RTHOOK(5);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) tr1;
	}/* NOTREACHED */
	
}

/* {CONF_LIBRARY}.class_by_name */
EIF_REFERENCE F1156_10476 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(9);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,loc3);
	RTLR(3,arg1);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,Result);
	RTLR(7,loc4);
	RTLR(8,loc5);
	RTLIU(9);
	
	RTEAA("class_by_name", 1155, Current, 5, 2, 16257);
	RTGC;
	RTHOOK(1);
	loc2 = F1156_10474(Current);
	RTHOOK(2);
	tb1 = '\0';
	if ((EIF_BOOLEAN)(loc2 != NULL)) {
		tr1 = F818_7224(RTCW(loc2), arg1);
		loc3 = tr1;
		tb1 = EIF_TEST(loc3);
	}
	if (tb1) {
		RTHOOK(3);
		loc1 = (EIF_REFERENCE) loc3;
	} else {
		RTHOOK(4);
		loc1 = (EIF_REFERENCE) arg1;
	}
	RTHOOK(5);
	{
		static EIF_TYPE_INDEX typarr0[] = {914,1078,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		Result = RTLNS(typres0.id, 914, _OBJSIZ_2_3_0_1_0_0_0_0_);
	}
	F911_7518(RTCW(Result));
	RTHOOK(6);
	tb1 = '\0';
	tb2 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_10_);
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		tr1 = F818_7224(loc4, loc1);
		loc5 = tr1;
		tb2 = EIF_TEST(loc5);
	}
	if (tb2) {
		tb2 = (RTNA((loc5)), ((EIF_BOOLEAN) 0));
		tb1 = (EIF_BOOLEAN) !tb2;
	}
	if (tb1) {
		RTHOOK(7);
		F915_7585(RTCW(Result), loc5);
	}
	RTHOOK(8);
	RTLE;
	RTEE;
	return Result;
}

/* {CONF_LIBRARY}.set_use_application_options */
void F1156_10480 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_use_application_options", 1155, Current, 0, 1, 16244);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current + O8186[Dtype(Current)-1155]) = (EIF_BOOLEAN) arg1;
	RTHOOK(3);
	RTEE;
}

/* {CONF_LIBRARY}.process */
void F1156_10482 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("process", 1155, Current, 0, 1, 16246);
	RTGC;
	RTHOOK(1);
	F1148_10367(Current, arg1);
	RTHOOK(2);
	F1274_12162(RTCW(arg1), Current);
	RTHOOK(3);
	RTLE;
	RTEE;
}

void EIF_Minit515 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
